%%% Main program for declarative-procedural WM model

%clear all

global E C P O M;

% Experiments: 1 = List-switch experiments 1, 2, and 5; 2 = List-switch
% experiment 4 (switching between 4 lists). 3 = Standard 2-task, 2-choice task-switching paradigm 
% 4 = Kiesel, Wendt, & Peters (2007) Experiment 2. 

expname = {'ListSwitch125', 'ListSwitch4', 'Tswi', 'Kiesel07'};

experiment = 1;  

E.nsubjects = 100;
E.ntrials = 50;
E.nsteps = 20;
E.setsize = 3;
E.CSI = [0.1, 1];
E.npretraining = 20;   % number of trials in pre-training of sets

C.timestep = 0.1;
C.preparation = 1;   %0: no explicit modeling of duration of retrieval of sets in set-selection module, 1 = explicit modeling... 
C.rt = 1;            %1: 1: LBA (Brown/Heathcote); 2: LCA (Usher/McClelland)

%    beta  focus asslrn cueprimg itmact uprate setdrift 
V = [0.05    0.3   0      0.12    0.06   0.5    3;       % 1: Basic model: binding strengthening + cue priming + response suppression
     0.05    0.3   0.02   0.12    0.12   0.5    3];      % 2: Basic model + association learning (for Kiesel 07 results)
 
model = 1;  

P.crit = V(model, 1);  % maximum tolerated abs. difference between actual and desired weight per connection in M.w (0.05)
P.focusing = V(model, 2);      % strengthening of associations and bindings through learning after retrieval (focusing), as proportion of learn rate
P.asslearnrate = V(model, 3);  % learnrate for associations between positions and items (or S-R associations). Positive values make congruency effects SMALLER!
P.cuepriming = V(model, 4);    % proportional carry-over of cue activation into next trial (= cue priming)
P.itemact = V(model, 5);       % activation of all items in the candidate set (should be >= rsupp to avoid negative activation)
P.rate = V(model, 6);          % rate for updating of WM from LTM (per time unit of 0.1 seconds)
P.setdrift = V(model, 7);      % drift rate for set retrieval
P.ltmcuedist = 100;    % exponential parameter for distance between cues for lists/task sets in LTM
P.cuedist = 100;       % exponential parameter for controlling distance between cues for items/responses (default = 2.0)
P.learnrate = 0.07;    % learnrate fr chunks in LTM (per event) and of associations in aLTM (0.07)
P.rsupp = 1;         % proportional response suppression parameter (1 = complete)
P.inhibrestor = 0.5; % restoration of activation from the candidate layer after inhibition (1 = complete restoration)

P.noise = 0.03;
P.boundary = 1.0;
P.accreset = 0.2;                % resetting of accumulator at end of trial (only for C.rt = 1)
P.accrate = 0.1;                 % Scaling parameter for drift rate for Usher/McClelland model of RT
P.accinhib = 1.0;                % inhibition term for Usher/McClelland model of RT (NOT divided by number of accumulators): 0.1 seems ok
P.accnetleak = 0.05;             % leakage term for Usher/McClelland model of RT
P.deadline = 5;

clear M
eval(expname{experiment});
filename = [expname{experiment}, '.', mat2str(model), '.dat'];
d = O.Result;
%eval(['save ' filename ' d -ASCII -TABS']);
fid = fopen(filename, 'w');
for line = 1:size(d,1)
    for col = 1:size(d,2)
        fprintf(fid, '%2.5f ', d(line,col));
    end
    fprintf(fid, '\n');
end
fclose(fid);




