function Kiesel07
% task switching experiment of Kiesel et al. 2007, E2: classification of
% digits, in one task only half the digits are used --> reduced congruency
% effect for those not used in the other task?

global E C P O M;

nconds = 1;
O.result = zeros(E.nsubjects*nconds*length(E.CSI)*E.ntrials*(E.nsteps-1), 9);
O.drifts = zeros(E.nsubjects*nconds*length(E.CSI)*E.ntrials*(E.nsteps-1), 9);
pointer = 1;

E.setsize = 8;    % 8 digits as stimuli
E.setprob = 0.5;  % probability of choosing first set - p(second set) = 1-p(first set)
E.CSI = 0.2; 
%E.npretraining = 500;  seems to be unnecessary for generating congruency effect 

% Representation of stimuli (= 8 digits, omitting 5)
M.cue = zeros(E.setsize);
for c = 1:E.setsize
    M.cue(c,:) = exp(-P.cuedist*(abs(c - (1:E.setsize))));
end
C.cunlist = 2;
C.cun = size(M.cue,2);

 % correct resonses to the four stimuli according to the two tasks 
List = [1 1 1 1 2 2 2 2;   % large-small task
        1 2 1 2 1 2 1 2];  % odd-even task

Congpos = List(1,:) == List(2,:);  %congruent positions
Bothused = [2 3 7 8;               %only use digits 2 3 8 9 in both tasks (8 and 9 coded as 7 and 8 because 5 is omitted), and use other digits only in odd-even task. 
            1 4 5 6];              %for counterbalancing: use the other digits
C.un = numel(unique(List));        %number of responses
P.crit = P.crit * C.un * C.cun;    %multiply with number of weights in M.w
for c = 1:C.cunlist
    M.listcue(c,:) = exp(-P.ltmcuedist*abs(c - (1:C.cunlist))); 
end
M.stim = diag(ones(1,C.un));  %localist representations of responses
M.winhib = -(ones(C.un)-diag(ones(1,C.un))).*(P.accinhib/C.un) - diag(ones(1,C.un)).*P.accnetleak;
% for Usher/McClelland: mutual inhibition is calibrated relative to number of accumulators by dividing P.accinhib by length(drift)



for id = 1:E.nsubjects
    for csi = 1:length(E.CSI)
            
        M = Pretraining(M, List);   %both tasks are trained equally often, using all stimuli (this represents pre-experimental training)
        bothused = Bothused(mod(id,2)+1,:);        
        
        for trial = 1:E.ntrials
            
            result = zeros(19,9);
            drifts = zeros(19,9);
            Set = zeros(1,E.nsteps); Pos = zeros(1,E.nsteps);
            M.candidates = P.itemact * ones(1, C.un);
            
            for r = 1:E.nsteps   %number of successive retrievals
                task2 = rand > E.setprob; %probabilistic choice of task 2 vs 1
                sel1 = task2 + 1;        
                Set(r) = sel1(1);
                if Set(r) == 2,  %odd-even task: select among all stimuli
                    sel2 = randperm(E.setsize); 
                    Pos(r) = sel2(1);         %select position to be recalled from = stimulus              
                end  
                if Set(r) == 1
                    sel2 = randperm(E.setsize/2);
                    Pos(r) = bothused(sel2(1));
                end
                list = List(Set(r),:);    %select the set (list) to be recalled from
              
                [M, rt, recall, drift] = Dotrial(M, Set(r), Pos(r), E.CSI(csi));
                
                % Collect data
                correct = recall == list(Pos(r));
                if r > 1,
                    O.response = [recall, correct, Pos(r), list];
                    digrep = List(Set(r), Pos(r)) == List(Set(r-1), Pos(r-1));
                    congruency = Congpos(Pos(r)); 
                    bused = ismember(Pos(r), bothused);
                    setswitch = Set(r)~=Set(r-1);
                    posswitch = Pos(r)~=Pos(r-1);
                    result(r-1,:) = [Set(r), setswitch, posswitch, digrep, congruency, bused, correct, rt, drift(list(Pos(r)))];
                    drifts(r-1,:) = [Set(r), setswitch, posswitch, digrep, congruency, bused, correct, drift(1:2)];
                end
                
            end
            O.result(pointer:pointer+(E.nsteps-2),:) = result;
            O.drifts(pointer:pointer+(E.nsteps-2),:) = drifts;
            pointer = pointer+(E.nsteps-1);
            
        end  %trial
    end  %CSI
end  %id


O.Result = aggregate(O.result(:, 1:6), O.result);
O.RT = aggregate(O.result(O.result(:,7)==1, 1:6), O.result(O.result(:, 7)==1, :));
try
    O.Errors = aggregate(O.result(O.result(:,7)==0, 1:6), O.result(O.result(:,7)==0, :));
catch
end

miny = 0;
maxy = 3; 
% plot with proportion used in other task, task switching, and congruency
legtext1 =  {'Task Rep incon', 'Task Rep con', 'Task Switch incon', 'Task Switch con'};

for both = 0:1
    column = 1;
    for swi = 0:1
        for con = 0:1
            selcon = (O.result(:,1) == 2) .* (O.result(:,2) == swi) .* (O.result(:,5) == con) .* (O.result(:,6) == both) .* (O.result(:,7) == 1);
            DV(both+1, column) = mean(O.result(selcon==1, 8));
            column = column + 1;
        end
    end
end
PreFigure
plot([0, 0.25], DV);
PostFigure([-0.05, 0.30, miny, maxy], 'p(use in large-small)', 'RT (s)', 'RT: Congruency effects on Odd-Even task', legtext1);

for both = 0:1
    column = 1;
    for swi = 0:1
        for con = 0:1
            selcon = (O.result(:,1) == 2) .* (O.result(:,2) == swi) .* (O.result(:,5) == con) .* (O.result(:,6) == both);
            DV(both+1, column) = mean(O.result(selcon==1, 7));
            column = column + 1;
        end
    end
end
PreFigure
plot([0, 0.25], 1-DV);
PostFigure([-0.05, 0.30, -0.05, 0.3], 'p(use in large-small)', 'RT (s)', 'Errors: Congruency effects on Odd-Even task', legtext1);

disp('     task    setswitch  posswitch  digrep  congruency  bothused  correct     rt      drift');
disp(O.Result);