function ListSwitch4

global E C P O M;

E.CSI = 0; 

O.result = zeros(E.nsubjects*E.ntrials*(E.nsteps-1), 7);
O.drifts = zeros(E.nsubjects*E.ntrials*(E.nsteps-1), 14);
pointer = 1;

clear M
for c = 1:E.setsize
    M.cue(c,:) = exp(-P.cuedist*(abs(c - (1:E.setsize))));
end

C.cun = size(M.cue,2);
C.cunlist = 4;                   % 4 lists
C.un = 9;                        % 9 digits
P.crit = P.crit * C.un * C.cun;  %multiply with number of weights in M.w
for c = 1:C.cunlist
    M.listcue(c,:) = exp(-P.ltmcuedist*abs(c - (1:C.cunlist))); 
end
M.stim = diag(ones(1,C.un));  %localist representations of digits
M.winhib = -(ones(C.un)-diag(ones(1,C.un))).*(P.accinhib/C.un) - diag(ones(1,C.un)).*P.accnetleak;
% for Usher/McClelland: mutual inhibition is calibrated relative to number of accumulators by dividing P.accinhib by length(drift)


liststructure = [1 2 3;  %structure defining lists such that every digit is repeated once, every position has 2x2 digits, and every list has 1 repeated digit. 
                 1 4 5;
                 6 2 5;
                 6 4 3];

O.preptime = {[], []};             
             
for id = 1:E.nsubjects
    
    list = randperm(C.un);
    Lists = list(liststructure);   %assigns digits to list structures
        
    M = Pretraining(M, Lists);
    
    for trial = 1:E.ntrials
        
        Selectedset = randperm(4);
        List = Lists(Selectedset(1:2), :);   %selects 2 lists at random
        for pos = 1:E.setsize
            if List(1,pos) == List(2,pos), reppos = pos; end   %detects the position in which the repeated digit sits
        end
               
        result = zeros(19,7);
        drifts = zeros(19,14);
        M.candidates = P.itemact * ones(1, C.un);
        Set = zeros(1,E.nsteps); Pos = zeros(1,E.nsteps);
        
        for r = 1:E.nsteps   %number of successive retrievals
            sel1 = randperm(2);
            sel2 = randperm(E.setsize);
            Set(r) = sel1(1);
            Pos(r) = sel2(1);         %select position to be recalled from
            list = List(Set(r),:);    %select the set (list) to be recalled from
            
            [M, rt, recall, drift, preptime] = Dotrial(M, Selectedset(Set(r)), Pos(r), E.CSI);
            
            % Collect data
            correct = recall == list(Pos(r));
            if r > 1,
                O.response = [recall, correct, Pos(r), list];
                digrep = List(Set(r), Pos(r)) == List(Set(r-1), Pos(r-1));
                congruency = Pos(r) == reppos; %easy detection of congruency: the congruent digits are in the same one position in both lists
                setswitch = Set(r)~=Set(r-1);
                posswitch = Pos(r)~=Pos(r-1);
                result(r-1,:) = [setswitch, posswitch, digrep, congruency, correct, rt, drift(list(Pos(r)))];
                drifts(r-1,:) = [setswitch, posswitch, digrep, congruency, correct, drift];
            end
            
        end
        O.result(pointer:pointer+(E.nsteps-2),:) = result;
        O.drifts(pointer:pointer+(E.nsteps-2),:) = drifts;
        pointer = pointer+(E.nsteps-1);
        O.preptime(setswitch+1) = {[cell2mat(O.preptime(setswitch+1)), preptime]};
        
    end  %trial
end  %id

O.Result = aggregate(O.result(:, 1:4), O.result);
O.RT = aggregate(O.result(O.result(:,5)==1, 1:4), O.result(O.result(:, 5)==1, :));
try
    O.Errors = aggregate(O.result(O.result(:,5)==0, 1:4), O.result(O.result(:,5)==0, :));
catch
end

%generate plot analogous to data plot for Oswi-Inhibition Experiment 5
allrep_con =   (O.result(:,1) == 0) .* (O.result(:,2) == 0) .* (O.result(:,3) == 1) .* (O.result(:,4) == 1) .*(O.result(:,5) == 1); 
allrep_incon = (O.result(:,1) == 0) .* (O.result(:,2) == 0) .* (O.result(:,3) == 1) .* (O.result(:,4) == 0) .*(O.result(:,5) == 1); 
listrep_posswi_digchg_con =   (O.result(:,1) == 0) .* (O.result(:,2) == 1) .* (O.result(:,3) == 0) .* (O.result(:,4) == 1) .* (O.result(:,5) == 1);
listrep_posswi_digchg_incon = (O.result(:,1) == 0) .* (O.result(:,2) == 1) .* (O.result(:,3) == 0) .* (O.result(:,4) == 0) .* (O.result(:,5) == 1);
listswi_posswi_digchg_con =   (O.result(:,1) == 1) .* (O.result(:,2) == 1) .* (O.result(:,3) == 0) .* (O.result(:,4) == 1) .* (O.result(:,5) == 1);
listswi_posswi_digchg_incon = (O.result(:,1) == 1) .* (O.result(:,2) == 1) .* (O.result(:,3) == 0) .* (O.result(:,4) == 0) .* (O.result(:,5) == 1);
listswi_posrep_digrep_con =   (O.result(:,1) == 1) .* (O.result(:,2) == 0) .* (O.result(:,3) == 1) .* (O.result(:,4) == 1) .* (O.result(:,5) == 1);

DV = zeros(2,3);  %first row = congruent, 2nd = incongruent, conditions = left to right

DV(1,1) = mean(O.result(allrep_con==1, 6)); 
DV(2,1) = mean(O.result(allrep_incon==1, 6));
DV(1,2) = mean(O.result(listrep_posswi_digchg_con==1, 6));
DV(2,2) = mean(O.result(listrep_posswi_digchg_incon==1, 6));
DV(1,3) = mean(O.result(listswi_posswi_digchg_con==1, 6));
DV(2,3) = mean(O.result(listswi_posswi_digchg_incon==1, 6));

PreFigure;
plot(1:3, DV');   
hold on
plot(3, mean(O.result(listswi_posrep_digrep_con==1, 6)));
PostFigure([0.5, 3.5, 0, 3], 'Condition', 'RT', 'Experiment 4', {'Congruent', 'Incongruent'});

 