function Tswi
% standard task-switching paradigm, with variable probability of each task
% during execution
% when one task's probability is set to 1 (or 0), this turns into a
% Stroop-like task.

global E C P O M;

nconds = 1;
O.result = zeros(E.nsubjects*nconds*length(E.CSI)*E.ntrials*(E.nsteps-1), 9);
O.drifts = zeros(E.nsubjects*nconds*length(E.CSI)*E.ntrials*(E.nsteps-1), 9);
pointer = 1;

E.setsize = 4;  %4 different stimulus categories, created by the 2x2 classification according to the 2 tasks (e.g,. color and shape)
E.setprob = 0.5;  %probability of choosing first set - p(second set) = 1-p(first set)

feature = [1 1;
    1 2;
    2 1;
    2 2];
% each stimulus (= cue) is coded by 2 features (e.g, color and shape).

% Configural representation of stimuli
for i = 1:4
    for j = 1:4
        dist(i,j) = sum(abs(feature(i,:)-feature(j,:)));
    end
end
M.cue = exp(-dist*P.cuedist);   %these are the stimuli, they serve as cues for the responses

C.cunlist = 2;
C.cun = size(M.cue,2);

List = [1 1 2 2;
        1 2 1 2];  %correct resonses to the four stimuli according to the two tasks

Congpos = List(1,:) == List(2,:);
C.un = numel(unique(List));   %number of responses
P.crit = P.crit * C.un * C.cun;  %multiply with number of weights in M.w
for c = 1:C.cunlist
    M.listcue(c,:) = exp(-P.ltmcuedist*abs(c - (1:C.cunlist)));
end
M.stim = diag(ones(1,C.un));  %localist representations of responses
M.winhib = -(ones(C.un)-diag(ones(1,C.un))).*(P.accinhib/C.un) - diag(ones(1,C.un)).*P.accnetleak;
% for Usher/McClelland: mutual inhibition is calibrated relative to number of accumulators by dividing P.accinhib by length(drift)

cond = 1;  %not used so far, so this is just a constant
for id = 1:E.nsubjects
    for csi = 1:length(E.CSI)
        
        M = Pretraining(M, List);   %both tasks are trained equally often
        
        for trial = 1:E.ntrials
            
            result = zeros(19,9);
            drifts = zeros(19,9);
            Set = zeros(1,E.nsteps); Pos = zeros(1,E.nsteps);
            M.candidates = P.itemact * ones(1, C.un);
            
            for r = 1:E.nsteps   %number of successive retrievals
                task2 = rand > E.setprob; %probabilistic choice of task 2 vs 1
                sel1 = task2 + 1;
                sel2 = randperm(E.setsize);
                Set(r) = sel1(1);
                Pos(r) = sel2(1);         %select position to be recalled from = stimulus
                list = List(Set(r),:);    %select the set (list) to be recalled from
                
                [M, rt, recall, drift] = Dotrial(M, Set(r), Pos(r), E.CSI(csi));
                
                % Collect data
                correct = recall == list(Pos(r));
                if r > 1,
                    O.response = [recall, correct, Pos(r), list];
                    digrep = List(Set(r), Pos(r)) == List(Set(r-1), Pos(r-1));
                    congruency = Congpos(Pos(r));
                    setswitch = Set(r)~=Set(r-1);
                    posswitch = Pos(r)~=Pos(r-1);
                    result(r-1,:) = [cond, E.CSI(csi), setswitch, posswitch, digrep, congruency, correct, rt, drift(list(Pos(r)))];
                    drifts(r-1,:) = [cond, E.CSI(csi), setswitch, posswitch, digrep, congruency, correct, drift(1:2)];
                end
                
            end
            O.result(pointer:pointer+(E.nsteps-2),:) = result;
            O.drifts(pointer:pointer+(E.nsteps-2),:) = drifts;
            pointer = pointer+(E.nsteps-1);
            
        end  %trial
    end  %CSI
end  %id


O.Result = aggregate(O.result(:, 1:6), O.result);
O.RT = aggregate(O.result(O.result(:,7)==1, 1:6), O.result(O.result(:, 7)==1, :));
try
    O.Errors = aggregate(O.result(O.result(:,7)==0, 1:6), O.result(O.result(:,7)==0, :));
catch
end

maxy = 3;
% plot with CSI, task switching, and congruency
legtext1 =  {'Task Rep incon', 'Task Switch incon', 'Task Rep con', 'Task Switch con'};
for csi = 1:length(E.CSI)
    for swi = 0:1
        for con = 0:1
            selcon = (O.result(:,2) == E.CSI(csi)) .* (O.result(:,3) == swi) .* (O.result(:,4) == 1) .* (O.result(:,5) == 0) .* (O.result(:,6) == con) .* (O.result(:,7) == 1);
            DV(csi,2*con+swi+1) = mean(O.result(selcon==1, 8));
        end
    end
end
PreFigure
plot(E.CSI, DV);
PostFigure([min(E.CSI)-0.1, max(E.CSI)+0.1, 0, maxy], 'CSI', 'RT (s)', 'Task switch effects by CSI and congruency', legtext1);


% plot with task switching, response repetition, congruency, separate panels for small and large CSI
placement = [0.1,  0.1, 0.35, 0.7;    %left, bottom, width, height; start with bottom row for condition 1 (rep in same position)
             0.55, 0.1, 0.35, 0.7];
legtext2 =  {'Resp Rep incon', 'Resp Switch incon', 'Resp Rep con', 'Resp Switch con'};
figure
for csi = 1:2
    for swi = 0:1
        for rswi = 0:1
            for con = 0:1
                selcon = (O.result(:,2) == E.CSI(csi)) .* (O.result(:,3) == swi) .* (O.result(:,5) == (1-rswi)) .* (O.result(:,6) == con) .* (O.result(:,7) == 1);
                DV(swi+1,2*con+rswi+1) = mean(O.result(selcon==1, 8));
            end
        end
    end
    PreFigure(2, placement(csi,:));
    plot(1:2, DV);
    PostFigure([0.8, 2.2, 0, maxy], 'Task repetition         Task switch', 'RT (s)', ['CSI = ', mat2str(E.CSI(csi))], legtext2);
end

disp('     cond     CSI     setswitch  posswitch  digrep  congruency  correct     rt      drift');
disp(O.Result);